@@ -693,15 +693,15 @@ gda_connection_drop_database (GdaConnection *cnc, const gchar *name)
  * gda_connection_create_table
  * @cnc: a #GdaConnection object.
  * @table_name: name of the table to be created.
- * @attributes_list: list of #GdaDataModelColumnAttributes for all fields in the table.
+ * @attributes_list: list of #GdaColumn for all fields in the table.
  * @index_list: list of #GdaDataModelIndex of all (multi column) index entries of a table.
  *
  * Creates a table on the given connection from the specified set of fields. In case of
- * none or single column index only, the various index fields can be set in #GdaDataModelColumnAttributes
- * and @index_list can be set to NULL. Index related values set in #GdaDataModelColumnAttributes
+ * none or single column index only, the various index fields can be set in #GdaColumn
+ * and @index_list can be set to NULL. Index related values set in #GdaColumn
  * should not overlap settings in @index_list. A table can only have one Primary Key for instance.
- * Either set it in #GdaDataModelColumnAttributes that is part of @attributes_list or in 
- * #GdaDataModelColumnIndexAttributes that is part of @index_list.
+ * Either set it in #GdaColumn that is part of @attributes_list or in 
+ * #GdaColumnIndex that is part of @index_list.
  *
  * Returns: %TRUE if successful, %FALSE otherwise.
  */
@@ -1072,24 +1072,21 @@ gda_connection_create_blob (GdaConnection *cnc, GdaBlob *blob)
 
 
 /**
- * gda_connection_escape_string
+ * gda_connection_value_to_sql_string
  * @cnc: a #GdaConnection object.
- * @from: String to be escaped.
- * @to: Buffer to save the escaped string to.
+ * @from: #GdaValue to convert from
  *
- * Natively escapes string with \ slashes etc.
+ * Produces a fully quoted and escaped string from a GdaValue
  *
- * Returns: %FALSE if the database does not support escaping.?
+ * Returns: escaped and quoted value or NULL if not supported.
  */
-gboolean
-gda_connection_escape_string (GdaConnection *cnc,
-			      const gchar *from,
-			      gchar *to)
+gchar *
+gda_connection_value_to_sql_string (GdaConnection *cnc,
+			      GdaValue *from)
 {
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (from != NULL, FALSE);
-	g_return_val_if_fail (to != NULL, FALSE);
 
 	/* execute the command on the provider */
-	return gda_server_provider_escape_string (cnc->priv->provider_obj, cnc, from, to);
+	return gda_server_provider_value_to_sql_string (cnc->priv->provider_obj, cnc, from);
 }
