@@ -80,7 +80,7 @@ gda_server_provider_class_init (GdaServerProviderClass *klass)
 	klass->supports = NULL;
 	klass->get_schema = NULL;
 	klass->create_blob = _gda_server_provider_create_blob;
-	klass->escape_string = NULL;
+	klass->value_to_sql_string = NULL;
 }
 
 static void
@@ -363,7 +363,7 @@ gda_server_provider_drop_database (GdaServerProvider *provider,
  * @provider: a #GdaServerProvider object.
  * @cnc: a #GdaConnection object.
  * @table_name: name of the table to create.
- * @attributes_list: list of #GdaDataModelColumnAttributes for all fields in the table.
+ * @attributes_list: list of #GdaColumn for all fields in the table.
  * @index_list: list of #GdaDataModelIndex for all (additional) indexes in the table.
  *
  * Proxy the call to the create_table method on the #GdaServerProvider class
@@ -644,28 +644,25 @@ gda_server_provider_create_blob (GdaServerProvider *provider,
 
 	return CLASS (provider)->create_blob (provider, cnc, blob);
 }
-
+ 
 /**
- * gda_server_provider_escape_string
+ * gda_server_provider_value_to_sql_string
  * @provider: a server provider.
  * @cnc: a #GdaConnection object.
- * @from: String to be escaped.
- * @to: Buffer to place the resulting escaped string.
+ * @from: #GdaValue to convert from
  *
- * Natively escapes string with \ slashes etc.
+ * Produces a fully quoted and escaped string from a GdaValue
  *
- * Returns: %FALSE if the database does not support escaping.?
+ * Returns: escaped and quoted value or NULL if not supported.
  */
-gboolean
-gda_server_provider_escape_string (GdaServerProvider *provider,
+gchar *
+gda_server_provider_value_to_sql_string (GdaServerProvider *provider,
 				   GdaConnection *cnc,
-				   const gchar *from,
-				   gchar *to)
+				   GdaValue *from)
 {
 	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (provider), FALSE);
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (from != NULL, FALSE);
-	g_return_val_if_fail (to != NULL, FALSE);
 
-	return CLASS (provider)->escape_string (provider, cnc, from, to);
+	return CLASS (provider)->value_to_sql_string (provider, cnc, from);
 }
