@@ -1,5 +1,5 @@
 /* GDA common library
- * Copyright (C) 1998-2002 The GNOME Foundation.
+ * Copyright (C) 1998 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *	Michael Lausch <michael@lausch.at>
@@ -84,6 +84,9 @@ clear_value (GdaValue *value)
 		g_free (value->value.v_numeric.number);
 		value->value.v_numeric.number = NULL;
 		break;
+	case GDA_VALUE_TYPE_TYPE :
+		value->value.v_type = GDA_VALUE_TYPE_NULL;
+		break;
 	default :
 		break;
 	}
@@ -1484,7 +1487,7 @@ gda_value_get_list (GdaValue *value)
 void
 gda_value_set_list (GdaValue *value, const GdaValueList *val)
 {
-	GList *values;
+	const GList *values;
 	g_return_if_fail (value != NULL);
 	g_return_if_fail (val != NULL);
 
@@ -2034,7 +2037,8 @@ gda_value_set_from_value (GdaValue *value, const GdaValue *from)
  * table:
  *
  * Returns: a string formatted according to the printf() style indicated in
- * the preceding table.
+ * the preceding table.  Free the value with a g_free() when you've finished
+ * using it. 
  */
 gchar *
 gda_value_stringify (GdaValue *value)
@@ -2050,7 +2054,8 @@ gda_value_stringify (GdaValue *value)
 	GString *str = NULL;
 	gchar *retval = NULL;
 
-	g_return_val_if_fail (value != NULL, NULL);
+	if (!value)
+		return g_strdup ("NULL");
 
 	switch (value->type){
 	case GDA_VALUE_TYPE_BIGINT:
@@ -2071,7 +2076,10 @@ gda_value_stringify (GdaValue *value)
 			retval = g_strdup (_("FALSE"));
 		break;
 	case GDA_VALUE_TYPE_STRING:
-		retval = g_strdup (gda_value_get_string (value));
+		if (gda_value_get_string (value))
+			retval = g_strdup (gda_value_get_string (value));
+		else
+			retval = g_strdup ("");
 		break;
 	case GDA_VALUE_TYPE_INTEGER:
 		retval = g_strdup_printf ("%d", gda_value_get_integer (value));
@@ -2299,7 +2307,18 @@ gda_value_compare (GdaValue *value1, GdaValue *value2)
                 retval = value1->value.v_smalluint - value2->value.v_smalluint;
                 break;
 	case GDA_VALUE_TYPE_STRING :
-		retval = strcmp (value1->value.v_string, value2->value.v_string);
+		if (value1->value.v_string && value2->value.v_string)
+			retval = strcmp (value1->value.v_string, value2->value.v_string);
+		else {
+			if (value1->value.v_string)
+				return 1;
+			else {
+				if (value2->value.v_string)
+					return -1;
+				else
+					return 0;
+			}
+		}
 		break;
 	case GDA_VALUE_TYPE_TIME :
 		retval = memcmp (&value1->value.v_time, &value2->value.v_time,
@@ -2331,6 +2350,36 @@ gda_value_compare (GdaValue *value1, GdaValue *value2)
 	return retval;
 }
 
+/**
+ * gda_value_compare_ext
+ * @value1: a #GdaValue to compare.
+ * @value2: the other #GdaValue to be compared to @value1.
+ *
+ * Like gda_value_compare(), compares two values of the same type, except that NULL values and values
+ * of type GDA_VALUE_TYPE_NULL are considered equals
+ *
+ * Returns: 0 if both contain the same value, an integer less than 0 if @value1 is less than @value2 or
+ * an integer greater than 0 if @value1 is greater than @value2.
+ */
+gint
+gda_value_compare_ext (GdaValue *value1, GdaValue *value2)
+{
+	if (!value1 || (value1->type == GDA_VALUE_TYPE_NULL)) {
+		/* value1 represents a NULL value */
+		if (!value2 || (value2->type == GDA_VALUE_TYPE_NULL))
+			return 0;
+		else
+			return 1;
+	}
+	else {
+		/* value1 does not represents a NULL value */
+		if (!value2 || (value2->type == GDA_VALUE_TYPE_NULL))
+			return -1;
+		else
+			return gda_value_compare (value1, value2);
+	}
+}
+
 /*
  * to_string
  * 
