@@ -117,6 +117,17 @@ table_changed_cb (GdaDataModel *model, gpointer user_data)
 	gda_xml_database_changed (xmldb);
 }
 
+static void
+table_name_changed_cb (GdaDataModel *model, gchar *old_name, gpointer user_data)
+{
+	GdaXmlDatabase *xmldb = (GdaXmlDatabase *) user_data;
+
+	g_return_if_fail (GDA_IS_XML_DATABASE (xmldb));
+
+	g_hash_table_remove (xmldb->priv->tables, old_name);
+	g_hash_table_insert (xmldb->priv->tables, gda_table_get_name (GDA_TABLE (model)), GDA_TABLE (model));
+}
+
 /*
  * GdaXmlDatabase class interface
  */
@@ -653,6 +664,7 @@ gda_xml_database_new_table (GdaXmlDatabase *xmldb, const gchar *name)
 
 	table = gda_table_new (name);
 	g_signal_connect (G_OBJECT (table), "changed", G_CALLBACK (table_changed_cb), xmldb);
+	g_signal_connect (G_OBJECT (table), "name_changed", G_CALLBACK (table_name_changed_cb), xmldb);
 	g_hash_table_insert (xmldb->priv->tables, g_strdup (name), table);
 	gda_xml_database_changed (xmldb);
 
@@ -690,6 +702,7 @@ gda_xml_database_new_table_from_model (GdaXmlDatabase *xmldb,
 
 	table = gda_table_new_from_model (name, model, add_data);
 	g_signal_connect (G_OBJECT (table), "changed", G_CALLBACK (table_changed_cb), xmldb);
+	g_signal_connect (G_OBJECT (table), "name_changed", G_CALLBACK (table_name_changed_cb), xmldb);
 	if (GDA_IS_TABLE (table)) {
 		g_hash_table_insert (xmldb->priv->tables, g_strdup (name), table);
 		gda_xml_database_changed (xmldb);
@@ -735,31 +748,31 @@ gda_xml_database_new_table_from_node (GdaXmlDatabase *xmldb, xmlNodePtr node)
 	/* parse the node */
 	for (children = node->xmlChildrenNode; children != NULL; children = children->next) {
 		if (!strcmp (children->name, OBJECT_FIELD)) {
-			GdaFieldAttributes *fa;
+			GdaColumn *column;
 
-			fa = gda_field_attributes_new ();
-			gda_field_attributes_set_defined_size (
-				fa, atoi (xmlGetProp (children, PROPERTY_SIZE)));
-			gda_field_attributes_set_name (
-				fa, xmlGetProp (children, PROPERTY_NAME));
-			gda_field_attributes_set_scale (
-				fa, atoi (xmlGetProp (children, PROPERTY_SCALE)));
-			gda_field_attributes_set_gdatype (
-				fa, gda_type_from_string (xmlGetProp (children, PROPERTY_GDATYPE)));
-			gda_field_attributes_set_allow_null (
-				fa, atoi (xmlGetProp (children, PROPERTY_ALLOW_NULL)));
-			gda_field_attributes_set_primary_key (
-				fa, atoi (xmlGetProp (children, PROPERTY_PRIMARY_KEY)));
-			gda_field_attributes_set_unique_key (
-				fa, atoi (xmlGetProp (children, PROPERTY_UNIQUE_KEY)));
-			gda_field_attributes_set_references (
-				fa, xmlGetProp (children, PROPERTY_REFERENCES));
-			gda_field_attributes_set_caption (
-				fa, xmlGetProp (children, PROPERTY_CAPTION));
-			gda_field_attributes_set_auto_increment (
-				fa, atoi (xmlGetProp (children, PROPERTY_AUTO)));
+			column = gda_column_new ();
+			gda_column_set_defined_size (
+				column, atoi (xmlGetProp (children, PROPERTY_SIZE)));
+			gda_column_set_name (
+				column, xmlGetProp (children, PROPERTY_NAME));
+			gda_column_set_scale (
+				column, atoi (xmlGetProp (children, PROPERTY_SCALE)));
+			gda_column_set_gdatype (
+				column, gda_type_from_string (xmlGetProp (children, PROPERTY_GDATYPE)));
+			gda_column_set_allow_null (
+				column, atoi (xmlGetProp (children, PROPERTY_ALLOW_NULL)));
+			gda_column_set_primary_key (
+				column, atoi (xmlGetProp (children, PROPERTY_PRIMARY_KEY)));
+			gda_column_set_unique_key (
+				column, atoi (xmlGetProp (children, PROPERTY_UNIQUE_KEY)));
+			gda_column_set_references (
+				column, xmlGetProp (children, PROPERTY_REFERENCES));
+			gda_column_set_caption (
+				column, xmlGetProp (children, PROPERTY_CAPTION));
+			gda_column_set_auto_increment (
+				column, atoi (xmlGetProp (children, PROPERTY_AUTO)));
 
-			gda_table_add_field (table, fa);
+			gda_table_add_field (table, column);
 		}
 		else if (!strcmp (children->name, OBJECT_DATA)) {
 			if (data) {
@@ -785,7 +798,30 @@ gda_xml_database_new_table_from_node (GdaXmlDatabase *xmldb, xmlNodePtr node)
 	/* add the table to the XML database object */
 	g_hash_table_insert (xmldb->priv->tables, g_strdup (name), table);
 	g_signal_connect (G_OBJECT (table), "changed", G_CALLBACK (table_changed_cb), xmldb);
+	g_signal_connect (G_OBJECT (table), "name_changed", G_CALLBACK (table_name_changed_cb), xmldb);
 	gda_xml_database_changed (xmldb);
 
 	return table;
 }
+
+gboolean
+gda_xml_database_remove_table (GdaXmlDatabase *xmldb, const gchar *name)
+{
+	GdaTable *table;
+	
+	g_return_val_if_fail (GDA_IS_XML_DATABASE (xmldb), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+
+	table = g_hash_table_lookup (xmldb->priv->tables, name);
+	if (table == NULL) {
+		gda_log_error (_("Table %s doesn't exist"), name);
+		return FALSE;
+	}
+
+	g_signal_handlers_disconnect_by_func (G_OBJECT (table), G_CALLBACK (table_changed_cb), xmldb);
+	g_signal_handlers_disconnect_by_func (G_OBJECT (table), G_CALLBACK (table_name_changed_cb), xmldb);
+	g_hash_table_remove (xmldb->priv->tables, name);
+	gda_xml_database_changed (xmldb);
+
+	return TRUE;
+}
