@@ -24,7 +24,7 @@
  */
 
 #include <libgda/gda-data-model-array.h>
-#include <libgda/gda-data-model-column-index-attributes.h>
+#include <libgda/gda-column-index.h>
 #include <libgda/gda-util.h>
 #include <libgda/gda-intl.h>
 #include <stdlib.h>
@@ -119,10 +119,9 @@ static GdaDataModel *gda_mysql_provider_get_schema (GdaServerProvider *provider,
 						    GdaConnectionSchema schema,
 						    GdaParameterList *params);
 
-static gboolean gda_mysql_provider_escape_string (GdaServerProvider *provider,
+static gchar *gda_mysql_provider_value_to_sql_string (GdaServerProvider *provider,
 						  GdaConnection *cnc,
-						  const gchar *from,
-						  gchar *to);
+						  GdaValue *from);
 
 static GObjectClass *parent_class = NULL;
 
@@ -158,7 +157,7 @@ gda_mysql_provider_class_init (GdaMysqlProviderClass *klass)
 	provider_class->rollback_transaction = gda_mysql_provider_rollback_transaction;
 	provider_class->supports = gda_mysql_provider_supports;
 	provider_class->get_schema = gda_mysql_provider_get_schema;
-	provider_class->escape_string = gda_mysql_provider_escape_string;
+	provider_class->value_to_sql_string = gda_mysql_provider_value_to_sql_string;
 }
 
 static void
@@ -538,7 +537,7 @@ gda_mysql_provider_create_table (GdaServerProvider *provider,
 {
 	MYSQL *mysql;
 	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
-	GdaDataModelColumnAttributes *dmca;
+	GdaColumn *dmca;
 	GdaDataModelIndex *dmi;
 	GString *sql;
 	gint i, rc;
@@ -569,25 +568,25 @@ gda_mysql_provider_create_table (GdaServerProvider *provider,
 		if (i>0)
 			g_string_append_printf (sql, ", ");
 
-		dmca = (GdaDataModelColumnAttributes *) g_list_nth_data ((GList *) attributes_list, i);
+		dmca = (GdaColumn *) g_list_nth_data ((GList *) attributes_list, i);
 
 		/* name */
-		g_string_append_printf (sql, "`%s` ", gda_data_model_column_attributes_get_name (dmca));
+		g_string_append_printf (sql, "`%s` ", gda_column_get_name (dmca));
 
 		/* data type */
-		value_type = gda_data_model_column_attributes_get_gdatype (dmca);
+		value_type = gda_column_get_gdatype (dmca);
 		mysql_data_type = gda_mysql_type_from_gda (value_type);
 		g_string_append_printf (sql, "%s", mysql_data_type);
 		g_free(mysql_data_type);
 
 		/* size */
-		size = gda_data_model_column_attributes_get_defined_size (dmca);
+		size = gda_column_get_defined_size (dmca);
 		if (value_type == GDA_VALUE_TYPE_STRING)
 			g_string_append_printf (sql, "(%ld)", size);
 		else if (value_type == GDA_VALUE_TYPE_NUMERIC)
 			g_string_append_printf (sql, "(%ld,%ld)",
-				gda_data_model_column_attributes_get_defined_size (dmca),
-				gda_data_model_column_attributes_get_scale (dmca));
+				gda_column_get_defined_size (dmca),
+				gda_column_get_scale (dmca));
 		else if (value_type == GDA_VALUE_TYPE_MONEY)
 			g_string_append_printf (sql, "(%ld)", size);
 
@@ -628,32 +627,32 @@ gda_mysql_provider_create_table (GdaServerProvider *provider,
 		}
 
 		/* NULL */
-		if (gda_data_model_column_attributes_get_allow_null (dmca) == TRUE)
+		if (gda_column_get_allow_null (dmca) == TRUE)
 			g_string_append_printf (sql, " NULL");
 		else
 			g_string_append_printf (sql, " NOT NULL");
 
 		/* auto increment */
-		if (gda_data_model_column_attributes_get_auto_increment (dmca) == TRUE)
+		if (gda_column_get_auto_increment (dmca) == TRUE)
 			g_string_append_printf (sql, "AUTO_INCREMENT");
 
 		/* (primary) key */
-		if (gda_data_model_column_attributes_get_primary_key (dmca) == TRUE)
+		if (gda_column_get_primary_key (dmca) == TRUE)
 			g_string_append_printf (sql, " PRIMARY KEY");
 		else
-			if (gda_data_model_column_attributes_get_unique_key (dmca) == TRUE)
+			if (gda_column_get_unique_key (dmca) == TRUE)
 				g_string_append_printf (sql, " UNIQUE");
 			
 		/* default value (in case of string, user needs to add "'" around the field) */
-                if (gda_data_model_column_attributes_get_default_value (dmca) != NULL) {
-			default_value = gda_value_stringify ((GdaValue *) gda_data_model_column_attributes_get_default_value (dmca));
+                if (gda_column_get_default_value (dmca) != NULL) {
+			default_value = gda_value_stringify ((GdaValue *) gda_column_get_default_value (dmca));
 			if ((default_value != NULL) && (*default_value != '\0'))
 				g_string_append_printf (sql, " DEFAULT %s", default_value);
 		}
 
 		/* any additional parameters */
-		if (gda_data_model_column_attributes_get_references (dmca) != NULL) {
-			references = (gchar *) gda_data_model_column_attributes_get_references (dmca);
+		if (gda_column_get_references (dmca) != NULL) {
+			references = (gchar *) gda_column_get_references (dmca);
 			if ((references != NULL) && (*references != '\0'))
 				g_string_append_printf (sql, " %s", references);
 		}
@@ -732,7 +731,7 @@ gda_mysql_provider_create_index (GdaServerProvider *provider,
 {
 	MYSQL *mysql;
 	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
-	GdaDataModelColumnIndexAttributes *dmcia;
+	GdaColumnIndex *dmcia;
 	GString *sql;
 	GList *col_list;
 	gchar *index_name, *col_ref, *idx_ref;
@@ -775,27 +774,27 @@ gda_mysql_provider_create_index (GdaServerProvider *provider,
 		if (i > 0)
 			g_string_append_printf (sql, ", ");
 
-		dmcia = (GdaDataModelColumnIndexAttributes *) g_list_nth_data ((GList *) col_list, i);
+		dmcia = (GdaColumnIndex *) g_list_nth_data ((GList *) col_list, i);
 
 		/* name */
-		g_string_append_printf (sql, "`%s` ", gda_data_model_column_index_attributes_get_column_name (dmcia));
+		g_string_append_printf (sql, "`%s` ", gda_column_index_get_column_name (dmcia));
 
 		/* size */
-		if (gda_data_model_column_index_attributes_get_defined_size (dmcia) > 0) {
-			size = gda_data_model_column_index_attributes_get_defined_size (dmcia);
+		if (gda_column_index_get_defined_size (dmcia) > 0) {
+			size = gda_column_index_get_defined_size (dmcia);
 			g_string_append_printf (sql, " (%d) ", size);
 		}
 
 		/* sorting */
-		sort = gda_data_model_column_index_attributes_get_sorting (dmcia);
+		sort = gda_column_index_get_sorting (dmcia);
 		if (sort == GDA_SORTING_DESCENDING)
 			g_string_append_printf (sql, " DESC ");
 		else
 			g_string_append_printf (sql, " ASC ");
 
 		/* any additional column parameters */
-		if (gda_data_model_column_index_attributes_get_references (dmcia) != NULL) {
-			col_ref = (gchar *) gda_data_model_column_index_attributes_get_references (dmcia);
+		if (gda_column_index_get_references (dmcia) != NULL) {
+			col_ref = (gchar *) gda_column_index_get_references (dmcia);
 			if ((col_ref != NULL) && (*col_ref != '\0'))
 				g_string_append_printf (sql, " %s ", col_ref);
 		}
@@ -1608,25 +1607,61 @@ gda_mysql_provider_get_schema (GdaServerProvider *provider,
 	return NULL;
 }
 
-
-gboolean
-gda_mysql_provider_escape_string (GdaServerProvider *provider,
-				  GdaConnection *cnc,
-				  const gchar *from,
-				  gchar *to)
+gchar *
+gda_mysql_provider_value_to_sql_string (
+				GdaServerProvider *provider, /* we dont actually use this!*/
+				GdaConnection *cnc,
+				GdaValue *from)
 {
-	MYSQL *mysql;
-	GdaMysqlProvider *myprv = (GdaMysqlProvider *) provider;
+	gchar *val_str;
+	gchar *ret;
 
-	g_return_val_if_fail (GDA_IS_MYSQL_PROVIDER (myprv), FALSE);
 	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
 	g_return_val_if_fail (from != NULL, FALSE);
-	g_return_val_if_fail (to != NULL, FALSE);
+	
+	val_str = gda_value_stringify (from);
+	if (!val_str)
+		return NULL;
 
-	mysql = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE);
-	if (!mysql) {
-		gda_connection_add_error_string (cnc, _("Invalid MYSQL handle"));
-		return 0;
+	switch (from->type) {
+		case GDA_VALUE_TYPE_BIGINT :
+		case GDA_VALUE_TYPE_DOUBLE :
+		case GDA_VALUE_TYPE_INTEGER :
+		case GDA_VALUE_TYPE_NUMERIC :
+		case GDA_VALUE_TYPE_SINGLE :
+		case GDA_VALUE_TYPE_SMALLINT :
+		case GDA_VALUE_TYPE_TINYINT :
+			ret = g_strdup (val_str);
+			break;
+		case GDA_VALUE_TYPE_TIMESTAMP:
+		case GDA_VALUE_TYPE_DATE :
+		case GDA_VALUE_TYPE_TIME :
+			ret = g_strdup_printf ("\"%s\"", val_str);
+			break;
+		default:
+		{
+			MYSQL *mysql;
+			char *quoted;
+			mysql = g_object_get_data (G_OBJECT (cnc), OBJECT_DATA_MYSQL_HANDLE);
+			
+			if (!mysql) {
+				gda_connection_add_error_string (cnc, _("Invalid MYSQL handle"));
+				return NULL;
+			}
+			quoted = ret = g_malloc(strlen(val_str) * 2 + 3);
+			*quoted++ 	= '\'';
+			quoted += mysql_real_escape_string (
+					mysql, quoted, val_str, strlen (val_str));
+					
+			*quoted++     	= '\'';
+			*quoted++     	= '\0';
+			ret = g_realloc(ret, quoted - ret + 1);
+		}
+		
 	}
-	return mysql_real_escape_string (mysql, to, from, strlen (from));
+
+	g_free (val_str);
+
+	return ret;
 }
+
