@@ -25,7 +25,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <libgda/gda-data-model-array.h>
-#include <libgda/gda-data-model-column-index-attributes.h>
+#include <libgda/gda-column-index.h>
 #include "gda-postgres.h"
 #include "gda-postgres-provider.h"
 
@@ -117,10 +117,10 @@ static gboolean gda_postgres_provider_create_blob (GdaServerProvider *provider,
 						   GdaConnection *cnc,
 						   GdaBlob *blob);
 
-static gboolean gda_postgres_provider_escape_string (GdaServerProvider *provider,
-						     GdaConnection *cnc,
-						     const gchar *from,
-						     gchar *to);
+gchar *
+gda_postgres_provider_value_to_sql_string (GdaServerProvider *provider, /* we dont actually use this!*/
+					GdaConnection *cnc,
+					GdaValue *from);
 				 		 
 typedef struct {
 	gchar *col_name;
@@ -178,7 +178,7 @@ gda_postgres_provider_class_init (GdaPostgresProviderClass *klass)
 	provider_class->supports = gda_postgres_provider_supports;
 	provider_class->get_schema = gda_postgres_provider_get_schema;
 	provider_class->create_blob = gda_postgres_provider_create_blob;
-	provider_class->escape_string = gda_postgres_provider_escape_string;
+	provider_class->value_to_sql_string = gda_postgres_provider_value_to_sql_string;
 }
 
 static void
@@ -825,7 +825,7 @@ gda_postgres_provider_create_table (GdaServerProvider *provider,
 				    const GList *index_list)
 {
 	GdaPostgresProvider *pg_prv = (GdaPostgresProvider *) provider;
-	GdaDataModelColumnAttributes *dmca;
+	GdaColumn *dmca;
 	GdaDataModelIndex *dmi;
 	GString *sql;
 	gint i;
@@ -848,17 +848,17 @@ gda_postgres_provider_create_table (GdaServerProvider *provider,
 		if (i>0)
 			g_string_append_printf (sql, ", ");
 			
-		dmca = (GdaDataModelColumnAttributes *) g_list_nth_data ((GList *) attributes_list, i);
+		dmca = (GdaColumn *) g_list_nth_data ((GList *) attributes_list, i);
 
 		/* name */	
-		g_string_append_printf (sql, "\"%s\" ", gda_data_model_column_attributes_get_name (dmca));
+		g_string_append_printf (sql, "\"%s\" ", gda_column_get_name (dmca));
 
 		/* data type; force serial to be used when auto_increment is set */
-		if (gda_data_model_column_attributes_get_auto_increment (dmca) == TRUE) {
+		if (gda_column_get_auto_increment (dmca) == TRUE) {
 			g_string_append_printf (sql, "serial");
 			value_type = GDA_VALUE_TYPE_INTEGER;
 		} else {
-			value_type = gda_data_model_column_attributes_get_gdatype (dmca);
+			value_type = gda_column_get_gdatype (dmca);
 			postgres_data_type = postgres_name_from_gda_type (value_type);
 			g_string_append_printf (sql, "%s", postgres_data_type);
 			g_free(postgres_data_type);
@@ -866,35 +866,35 @@ gda_postgres_provider_create_table (GdaServerProvider *provider,
 
 		/* size */
 		if (value_type == GDA_VALUE_TYPE_STRING)
-			g_string_append_printf (sql, "(%ld)", gda_data_model_column_attributes_get_defined_size (dmca));
+			g_string_append_printf (sql, "(%ld)", gda_column_get_defined_size (dmca));
 		else if (value_type == GDA_VALUE_TYPE_NUMERIC)
 			g_string_append_printf (sql, "(%ld,%ld)", 
-				gda_data_model_column_attributes_get_defined_size (dmca),
-				gda_data_model_column_attributes_get_scale (dmca));
+				gda_column_get_defined_size (dmca),
+				gda_column_get_scale (dmca));
 		
 		/* NULL */
-		if (gda_data_model_column_attributes_get_allow_null (dmca) == TRUE)
+		if (gda_column_get_allow_null (dmca) == TRUE)
 			g_string_append_printf (sql, " NULL");
 		else
 			g_string_append_printf (sql, " NOT NULL");
 	
 		/* (primary) key */
-		if (gda_data_model_column_attributes_get_primary_key (dmca) == TRUE)
+		if (gda_column_get_primary_key (dmca) == TRUE)
 			g_string_append_printf (sql, " PRIMARY KEY");
 		else
-			if (gda_data_model_column_attributes_get_unique_key (dmca) == TRUE)
+			if (gda_column_get_unique_key (dmca) == TRUE)
 				g_string_append_printf (sql, " UNIQUE");
 
 		/* default value (in case of string, user needs to add "'" around the field) */
-		if (gda_data_model_column_attributes_get_default_value (dmca) != NULL) {
-			default_value = gda_value_stringify ((GdaValue *) gda_data_model_column_attributes_get_default_value (dmca));
+		if (gda_column_get_default_value (dmca) != NULL) {
+			default_value = gda_value_stringify ((GdaValue *) gda_column_get_default_value (dmca));
 			if ((default_value != NULL) && (*default_value != '\0'))
 				g_string_append_printf (sql, " DEFAULT %s", default_value);
 		}
 
 		/* any additional parameters */			
-		if (gda_data_model_column_attributes_get_references (dmca) != NULL) {
-			references = (gchar *) gda_data_model_column_attributes_get_references (dmca);
+		if (gda_column_get_references (dmca) != NULL) {
+			references = (gchar *) gda_column_get_references (dmca);
 			if ((references != NULL) && (*references != '\0'))
 				g_string_append_printf (sql, " %s", references);
 		}
@@ -960,7 +960,7 @@ gda_postgres_provider_create_index (GdaServerProvider *provider,
 				    const gchar *table_name)
 {
 	GdaPostgresProvider *pg_prv = (GdaPostgresProvider *) provider;
-	GdaDataModelColumnIndexAttributes *dmcia;
+	GdaColumnIndex *dmcia;
 	GString *sql;
 	GList *col_list;
 	gchar *index_name, *col_ref, *idx_ref;
@@ -999,14 +999,14 @@ gda_postgres_provider_create_index (GdaServerProvider *provider,
 		if (i > 0)
 			g_string_append_printf (sql, ", ");
 			
-		dmcia = (GdaDataModelColumnIndexAttributes *) g_list_nth_data ((GList *) col_list, i);
+		dmcia = (GdaColumnIndex *) g_list_nth_data ((GList *) col_list, i);
 
 		/* name */	
-		g_string_append_printf (sql, "\"%s\" ", gda_data_model_column_index_attributes_get_column_name (dmcia));
+		g_string_append_printf (sql, "\"%s\" ", gda_column_index_get_column_name (dmcia));
 
 		/* any additional column parameters */
-		if (gda_data_model_column_index_attributes_get_references (dmcia) != NULL) {
-			col_ref = (gchar *) gda_data_model_column_index_attributes_get_references (dmcia);
+		if (gda_column_index_get_references (dmcia) != NULL) {
+			col_ref = (gchar *) gda_column_index_get_references (dmcia);
 			if ((col_ref != NULL) && (*col_ref != '\0'))
 				g_string_append_printf (sql, " %s ", col_ref);
 		}
@@ -2505,16 +2505,57 @@ static gboolean gda_postgres_provider_create_blob (GdaServerProvider *provider,
 	return gda_postgres_blob_create (blob, cnc);
 }
 
-gboolean
-gda_postgres_provider_escape_string (GdaServerProvider *provider,
-				     GdaConnection *cnc,
-				     const gchar *from,
-				     gchar *to)
+gchar *
+gda_postgres_provider_value_to_sql_string (
+				GdaServerProvider *provider, /* we dont actually use this!*/
+				GdaConnection *cnc,
+				GdaValue *from)
 {
-	g_return_val_if_fail (GDA_IS_POSTGRES_PROVIDER (provider), FALSE);
-	g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-	g_return_val_if_fail (from != NULL, FALSE);
-	g_return_val_if_fail (to != NULL, FALSE);
+	gchar *val_str;
+	gchar *ret;
+	
+	g_return_val_if_fail (from != NULL, NULL);
 
-	return (unsigned long)  PQescapeString (to, from, (size_t) strlen (from));
+	val_str = gda_value_stringify (from);
+	if (!val_str)
+		return NULL;
+
+	switch (from->type) {
+		case GDA_VALUE_TYPE_BIGINT :
+		case GDA_VALUE_TYPE_DOUBLE :
+		case GDA_VALUE_TYPE_INTEGER :
+		case GDA_VALUE_TYPE_NUMERIC :
+		case GDA_VALUE_TYPE_SINGLE :
+		case GDA_VALUE_TYPE_SMALLINT :
+		case GDA_VALUE_TYPE_TINYINT :
+			ret = g_strdup (val_str);
+			break;
+		case GDA_VALUE_TYPE_TIMESTAMP:
+		case GDA_VALUE_TYPE_DATE :
+		case GDA_VALUE_TYPE_TIME :
+			ret = g_strdup_printf ("\"%s\"", val_str);
+			break;
+		case GDA_VALUE_TYPE_BINARY:
+		{
+			int qlen;
+			char *quoted;
+			quoted = PQescapeBytea(val_str, (size_t) strlen(val_str), &qlen);
+			ret = g_strdup_printf ("\"%s\"", quoted);
+			PQfreemem(quoted);
+			break;
+		}
+		default :
+		{
+			char *quoted;
+			quoted = ret = g_malloc(strlen(val_str) * 2 + 3);
+			*quoted++     	= '\'';
+			quoted += PQescapeString (quoted, val_str, (size_t) strlen (val_str));
+			*quoted++     	= '\'';
+			*quoted++     	= '\0';
+			ret = g_realloc(ret, quoted - ret + 1);
+		}
+	}
+	g_free (val_str);
+
+	return ret;
 }
