@@ -528,7 +528,7 @@ get_table_fields (GdaConnection *cnc, GdaXmlDatabase *xmldb, GdaParameterList *p
 
 	cols = gda_data_model_get_n_columns (GDA_DATA_MODEL (table));
 	for (i = 0; i < cols; i++) {
-		GdaFieldAttributes *fa;
+		GdaColumn *fa;
 		GList *value_list = NULL;
 
 		fa = gda_data_model_describe_column (GDA_DATA_MODEL (table), i);
@@ -540,16 +540,16 @@ get_table_fields (GdaConnection *cnc, GdaXmlDatabase *xmldb, GdaParameterList *p
 			return NULL;
 		}
 
-		value_list = g_list_append (value_list, gda_value_new_string (gda_field_attributes_get_name (fa)));
-		value_list = g_list_append (value_list, gda_value_new_string (gda_type_to_string (gda_field_attributes_get_gdatype (fa))));
-		value_list = g_list_append (value_list, gda_value_new_integer (gda_field_attributes_get_defined_size (fa)));
-		value_list = g_list_append (value_list, gda_value_new_integer (gda_field_attributes_get_scale (fa)));
+		value_list = g_list_append (value_list, gda_value_new_string (gda_column_get_name (fa)));
+		value_list = g_list_append (value_list, gda_value_new_string (gda_type_to_string (gda_column_get_gdatype (fa))));
+		value_list = g_list_append (value_list, gda_value_new_integer (gda_column_get_defined_size (fa)));
+		value_list = g_list_append (value_list, gda_value_new_integer (gda_column_get_scale (fa)));
 		value_list = g_list_append (value_list, gda_value_new_boolean (FALSE));
 		value_list = g_list_append (value_list, gda_value_new_boolean (FALSE));
 		value_list = g_list_append (value_list, gda_value_new_boolean (FALSE));
 		value_list = g_list_append (value_list, gda_value_new_string (""));
 
-		gda_field_attributes_free (fa);
+		gda_column_free (fa);
 	}
 
 	return GDA_DATA_MODEL (recset);
@@ -569,7 +569,7 @@ add_string_row (GdaDataModelArray *recset, const gchar *str)
 	list.next = NULL;
 	list.prev = NULL;
 
-	gda_data_model_append_row (GDA_DATA_MODEL (recset), &list);
+	gda_data_model_append_values (GDA_DATA_MODEL (recset), &list);
 
 	gda_value_free (value);
 }
@@ -612,7 +612,7 @@ get_tables (GdaConnection *cnc, GdaXmlDatabase *xmldb)
 
 			value = gda_value_new_string ((const gchar *) l->data);
 			value_list = g_list_append (NULL, value);
-			gda_data_model_append_row (GDA_DATA_MODEL (recset),
+			gda_data_model_append_values (GDA_DATA_MODEL (recset),
 						   (const GList *) value_list);
 
 			gda_value_free (value);
@@ -636,7 +636,7 @@ add_type_row (GdaDataModelArray *recset, const gchar *type, const gchar *owner,
 	value_list = g_list_append (value_list, gda_value_new_string (comments));
 	value_list = g_list_append (value_list, gda_value_new_type (gda_type));
 
-	gda_data_model_append_row (GDA_DATA_MODEL (recset), value_list);
+	gda_data_model_append_values (GDA_DATA_MODEL (recset), value_list);
 
 	g_list_foreach (value_list, (GFunc) gda_value_free, NULL);
 	g_list_free (value_list);
